@@ -1,6 +1,6 @@
 from datetime import datetime
 from optparse import make_option
-from distutils.version import StrictVersion
+from distutils.version import LooseVersion
 import os
 import ssl
 import sys
@@ -9,6 +9,7 @@ from django.core.servers.basehttp import WSGIRequestHandler
 from django.core.servers.basehttp import WSGIServer
 from django.core.management.base import CommandError
 from django.core.management.commands import runserver
+from django.contrib.staticfiles.handlers import StaticFilesHandler
 from django.utils.importlib import import_module
 from django import get_version
 
@@ -17,7 +18,7 @@ try:
 except ImportError:
     from socket import error as WSGIServerException
 
-if StrictVersion(get_version()) >= StrictVersion('1.5'):
+if LooseVersion(get_version()) >= LooseVersion('1.5'):
     from django.utils._os import upath
 else:
     upath = unicode
@@ -30,6 +31,14 @@ class SecureHTTPServer(WSGIServer):
                                       ssl_version=ssl.PROTOCOL_SSLv3,
                                       cert_reqs=ssl.CERT_NONE)
 
+
+class WSGIRequestHandler(WSGIRequestHandler):
+    def get_environ(self):
+        env = super(WSGIRequestHandler, self).get_environ()
+        env['HTTPS'] = 'on'
+        return env
+
+
 def default_ssl_files_dir():
     app_module = import_module("sslserver")
     mod_path = os.path.dirname(upath(app_module.__file__))
@@ -51,6 +60,20 @@ class Command(runserver.Command):
 
     help = "Run a Django development server over HTTPS"
 
+    def get_handler(self, *args, **options):
+        """
+        Returns the static files serving handler wrapping the default handler,
+        if static files should be served. Otherwise just returns the default
+        handler.
+
+        """
+        handler = super(Command, self).get_handler(*args, **options)
+        use_static_handler = options.get('use_static_handler', True)
+        insecure_serving = options.get('insecure_serving', False)
+        if use_static_handler:
+            return StaticFilesHandler(handler)
+        return handler
+
     def check_certs(self, key_file, cert_file):
         # TODO: maybe validate these? wrap_socket doesn't...
 
@@ -107,7 +130,8 @@ class Command(runserver.Command):
             server.set_app(handler)
             server.serve_forever()
 
-        except WSGIServerException as e:
+        except WSGIServerException:
+            e = sys.exc_info()[1]
             # Use helpful error messages instead of ugly tracebacks.
             ERRORS = {
                 13: "You don't have permission to access that port.",
